# Extract PharmGKB variants

### A simple way to extract SNV and HLA alleles from exome data

This script extract known variants in PharmGKB database from exome data. It is based on two steps, first HLA genotyping with HLAscan and SNV extraction with 
pysam library. On output, you have a HTML file readable with any web navigator (Internet Explorer, Firefox or Chrome)

## Table of Contents

* [Requirements](#requirements)
* [Installation](#installation)
* [Usage](#usage)

## Requirements

* HLAscan v1.0:
    * [download zip file](https://github.com/SyntekabioTools/HLAscan/releases/download/v1.0.0/HLAscan.v1.0.Files.zip)
    * [Publication](https://bmcbioinformatics.biomedcentral.com/track/pdf/10.1186/s12859-017-1671-3)

Reference : Ka, S., Lee, S., Hong, J., Cho, Y., ... & Jung, J. (2017). HLAscan: genotyping of the HLA region using next-generation sequencing data. BMC bioinformatics, 18(1), 258.

* Python2.7:
    * Tested with python 2.7.18
    * library: pysam , htmltag (required sphinx)
    * [download python](https://www.python.org/download/releases/python-2718/)

* PharmGKB csv file
    * [download csv file](https://api.pharmgkb.org/v1/download/file/data/clinicalAnnotations.zip)
    * we will use the **clinical_annotations.tsv** for the next step
    * Change all star alleles by DBSnp variants if possible, example : CYP2C9*2 become rs1799853
    * Use [CPIC](https://cpicpgx.org/) recommandations or [PharmVar](https://www.pharmvar.org/) website for the conversion

## Installation

* First install library with pip:
    * pip2.7 install pysam
    * pip2.7 install sphinx
    * pip2.7 install htmltag

* Clone this repository

## Usage

### Data test

* NA12878 data test : 
    * You can dowload vcf file provided by exome sequencing at this link : 
https://ftp-trace.ncbi.nlm.nih.gov/giab/ftp/data/NA12878/Nebraska_NA12878_HG001_TruSeq_Exome/NIST-hg001-7001-b-gatk.vcf

    * Bam file is provided with HLAscan

### Execution

    bash Extract_PharmGKB_Variants.sh

    <Mandatory>
	-p <path to PharmGKB file> : Path to PharmGKB tsv file download at PharmGKB site.
	-b <path to bam file> : Path to bam file provided by alignement.
	-s <path to hlascan files> : Path to HLAscan tools download and unzipped.
	-v <path to vcf file> : Path to vcf file provided by variant calling
	-o <output_path>: Output path.

    -h print help and exit

#### Data test

    bash Extract_PharmGKB_Variants.sh -p <path/to/clinical_annotations.tsv> -b data_test/NA12878.5gene.bam -s <path to HLAscan files> -v data_test/NIST-hg001-7001-b-gatk.vcf  -o data_test/